@@ -174,7 +174,7 @@ borrowed them from elsewhere.
 =head2 method gamma-fix-values
 
 This applies the gamma adjustment mapping to the supplied Array of values
-returning the adjusted values as an Array
+returning the adjust values as an Array
 
 =head2 method reset
 
@@ -184,7 +184,7 @@ this.
 
 =end pod
 
-class RPi::Device::PiGlow:ver<0.0.3>:auth<github:jonathanstowe>:api<1.0> {
+class RPi::Device::PiGlow:ver<0.0.1>:auth<github:jonathanstowe> {
     use RPi::Device::SMBus;
 
     constant CMD_ENABLE_OUTPUT    = 0x00;
@@ -216,47 +216,48 @@ class RPi::Device::PiGlow:ver<0.0.3>:auth<github:jonathanstowe>:api<1.0> {
 
     constant NUM_LEDS             = 18;
 
-    subset Ring     of Int where { $_ >= 0 && $_ <= 5 };
-    subset Arm      of Int where { $_ >= 0 && $_ <= 2 };
-    subset Colour   of Str where { get-colour-table{$_}:exists };
+    subset Ring of Int where { $_ >= 0 && $_ <= 5 };
+    subset Arm of Int where { $_ >= 0 && $_ <= 2 };
+    subset Colour of Str where { get-colour-table{$_}:exists };
 
     has RPi::Device::SMBus::DevicePath  $.i2c-bus-device-path = '/dev/i2c-1';
     has RPi::Device::SMBus::I2C-Address $.i2c-device-address  = 0x054;
 
     has RPi::Device::SMBus              $.device-smbus;
 
-    method device-smbus( --> RPi::Device::SMBus ) handles <write-byte-data write-block-data write-i2c-block-data> {
-        $!device-smbus //= do  {
-            RPi::Device::SMBus.new(
-                address => $!i2c-device-address, 
-                device  =>  $!i2c-bus-device-path
-            );
+    method device-smbus() returns RPi::Device::SMBus handles <write-byte-data write-block-data> {
+        if not $!device-smbus.defined {
+            $!device-smbus = RPi::Device::SMBus.new(
+                                                    address => $!i2c-device-address, 
+                                                    device  =>  $!i2c-bus-device-path
+                                                   );
         }
+        $!device-smbus;
     }
 
     has @!led-bank-enable-registers = CMD_ENABLE_LEDS_1, CMD_ENABLE_LEDS_2, CMD_ENABLE_LEDS_3;
 
-    method update( --> Int ) {
+    method update() returns Int {
         self.write-byte-data(CMD_UPDATE, 0xFF);
     }
 
-    method enable-output( --> Int ) {
+    method enable-output() returns Int {
         self.write-byte-data(CMD_ENABLE_OUTPUT, 0x01);
     }
 
-    method enable-all-leds( --> Int ) {
-        self.write-i2c-block-data(CMD_ENABLE_LEDS, [0xFF, 0xFF, 0xFF]);
+    method enable-all-leds() returns Int {
+        self.write-block-data(CMD_ENABLE_LEDS, [0xFF, 0xFF, 0xFF]);
     }
 
-    method write-all-leds(@values is copy, :$fix --> Int ) {
+    method write-all-leds(@values is copy, :$fix) returns Int {
         if $fix {
             @values = self.gamma-fix-values(@values);
         }
-        self.write-i2c-block-data(CMD_SET_PWM_VALUES, @values);
+        self.write-block-data(CMD_SET_PWM_VALUES, @values);
         self.update;
     }
 
-    method all-off( --> Int ) {
+    method all-off() returns Int {
 
         my @vals = 0 xx NUM_LEDS;
         self.write-all-leds(@vals);
@@ -271,7 +272,7 @@ class RPi::Device::PiGlow:ver<0.0.3>:auth<github:jonathanstowe>:api<1.0> {
 
     has @.led-table handles ( 'get-led-register' => 'AT-POS' ) = get-led-table();
 
-    sub get-led-table( --> Array ) {
+    sub get-led-table() returns Array {
         return [
              CMD_SET_PWM_VALUE_7,
              CMD_SET_PWM_VALUE_8,
@@ -296,7 +297,7 @@ class RPi::Device::PiGlow:ver<0.0.3>:auth<github:jonathanstowe>:api<1.0> {
 
     has @.ring-table;
 
-    method ring-table( --> Array ) {
+    method ring-table() returns Array {
         if @!ring-table.elems == 0 {
             for ^6 -> $led  {
                 for ^3 -> $arm {
@@ -308,7 +309,7 @@ class RPi::Device::PiGlow:ver<0.0.3>:auth<github:jonathanstowe>:api<1.0> {
         return @!ring-table;
     }
 
-    method get-ring-leds(Ring $ring --> Array ) {
+    method get-ring-leds(Ring $ring) returns Array {
         self.ring-table[$ring].Array
     }
 
@@ -320,7 +321,7 @@ class RPi::Device::PiGlow:ver<0.0.3>:auth<github:jonathanstowe>:api<1.0> {
 
     has @.arm-table = get-arm-table();
 
-    sub get-arm-table( --> Array ) {
+    sub get-arm-table() returns Array {
         return [
                 [0,1,2,3,4,5],
                 [6,7,8,9,10,11],
@@ -340,7 +341,7 @@ class RPi::Device::PiGlow:ver<0.0.3>:auth<github:jonathanstowe>:api<1.0> {
 
     has %.colour-table handles ( 'colours' => 'keys' ) = get-colour-table();
 
-    sub get-colour-table( --> Hash ) {
+    sub get-colour-table() returns Hash {
         return {
                     white   => [5,11,17],
                     blue    => [4,10,16],
@@ -351,7 +352,7 @@ class RPi::Device::PiGlow:ver<0.0.3>:auth<github:jonathanstowe>:api<1.0> {
                };
     }
 
-    method get-colour-leds(Colour $colour --> Array ) {
+    method get-colour-leds(Colour $colour) returns Array {
         self.colour-table{$colour}.Array;
     }
 
@@ -363,7 +364,7 @@ class RPi::Device::PiGlow:ver<0.0.3>:auth<github:jonathanstowe>:api<1.0> {
 
     has @.gamma-table handles ( 'map-gamma' => 'AT-POS' ) = get-gamma-table();
 
-    sub get-gamma-table( --> Array ) {
+    sub get-gamma-table() returns Array {
         return [
             0,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,
             1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,
@@ -387,12 +388,12 @@ class RPi::Device::PiGlow:ver<0.0.3>:auth<github:jonathanstowe>:api<1.0> {
         ];
     }
 
-    method gamma-fix-values(@values is copy --> Array ) {
+    method gamma-fix-values(@values is copy) returns Array {
         @values = @values.map({ self.map-gamma($_) });
         return @values;
     }
 
-    method reset(--> Int ) {
+    method reset() returns Int {
         self.write-byte-data(CMD_RESET, 0xFF);
     }
 
